@@ -30,12 +30,21 @@ def safe_concat(large, small):
 
 
 class FrozenDict(dict):
-    def __init__(self, debug=True):
-        super().__init__()
-        self.debug = debug
+    def __init__(self, _dict):
+        super().__init__(_dict)
+
+    def prompt(self, key, value):
+        raise ValueError(f'*** '
+                         f'Attempt to modify frozen dict '
+                         f'[{key} : {self[key]}] with [{key} : {value}]'
+                         f' ***')
 
     def __setitem__(self, key, value):
         if key not in self:
             super(FrozenDict, self).__setitem__(key, value)
-        elif self.debug:
-            print(f'*** Attempt to modify frozen dict [{key} : {self[key]}] with [{key} : {value}] ***')
+        else:
+            self.prompt(key, value)
+
+    def update(self, **kw):
+        for k, v in kw.items():
+            self[k] = v
